@@ -315,7 +315,7 @@ class USSD_Controller:
 	def call_external_script( self, ussd_code, language ):
 		self.cb_ready = 0
 		self.cb_reply = "";
-		p = Popen(['/usr/bin/ussdquery.py', ussd_code, ussd_languages[language]], stdout=PIPE)
+		p = Popen(['/usr/bin/ussdquery.py', ussd_code, "-l", ussd_languages[language]], stdout=PIPE)
 		gobject.io_add_watch( p.stdout, gobject.IO_IN | gobject.IO_PRI | gobject.IO_HUP | gobject.IO_ERR , self.callback_ussd_data )
 
 	def ussd_renew(self, widget, event):
@@ -485,6 +485,9 @@ class UssdConfigDialog(gtk.Dialog):
 
 		retryhelp = gtk.Button("?")
 		retryhelp.connect("clicked", self.on_show_retryhelp)
+		
+		numberhelp = gtk.Button("?")
+		numberhelp.connect("clicked", self.on_show_number_help)
 
 		area = hildon.PannableArea()
 		self.vbox.add(area)
@@ -495,8 +498,10 @@ class UssdConfigDialog(gtk.Dialog):
 		numberLabel = gtk.Label(_("USSD number"))
 		numberLabel.set_alignment(0,0)
 		numberLabel.set_size_request(100, -1)
+		numberhelp.set_size_request(1, -1)
 		self.ussdNumber.set_size_request(200, -1)
 		numberBox.add(numberLabel)
+		numberBox.add(numberhelp)
 		numberBox.add(self.ussdNumber)
 		vbox.add(numberBox)
 
@@ -524,8 +529,6 @@ class UssdConfigDialog(gtk.Dialog):
 		vbox.add(self.parser)
 		
 		b_parserBox = gtk.HBox()
-#		parserLabel = gtk.Label(_("Parser"))
-#		parserLabel.set_alignment(0,0)
 		self.show_box.set_size_request(200, -1)
 		bphelp.set_size_request(10, -1)
 		b_parserBox.add(self.show_box)
@@ -622,6 +625,11 @@ class UssdConfigDialog(gtk.Dialog):
 		dialog.run()
 		dialog.destroy()
 	
+	def on_show_number_help(self, widget):
+		dialog = pHelpDialog(_("Format help"), _("USSD number. To perform USSD menu navigation divide queries vith spacebars. For xample '*100# 1' means 1st entry in *100# menu."))
+		dialog.run()
+		dialog.destroy()
+	
 	def on_error_regexp(self, error):
 		dialog = pHelpDialog(_("Regexp syntax error"), error )
 		dialog.run()
@@ -705,7 +713,7 @@ def check_regexp(regexp):
 
 def check_number(number):
 	for s in number :
-		if not (s in ["1", "2", "3", "4", "5", "6", "7", "8", "9", "0", "+", "*", "#"]) :
+		if not (s in ["1", "2", "3", "4", "5", "6", "7", "8", "9", "0", "+", "*", "#", " "]) :
 			return False
 	return True
 
@@ -757,6 +765,7 @@ class UssdWidgetPlugin(hildondesktop.HomePluginItem):
 		if config[6]:
 			self.controller.ussd_renew(self, None)
 
+		self.label.modify_font(config[8])
 		self.controller.reset_timed_renew()
 		hildondesktop.HomePluginItem.do_show(self)
 	
